@@ -9,11 +9,11 @@
 *** hub
 
 ** Author: Ralph Amissah
-  <ralph@amissah.com>
-  <ralph.amissah@gmail.com>
+  [ralph@amissah.com]
+  [ralph.amissah@gmail.com]
 
 ** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Ralph Amissah,
+  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
   All Rights Reserved.
 
 ** License: GPL 3 or later:
@@ -33,14 +33,12 @@
   more details.
 
   You should have received a copy of the GNU General Public License along with
-  this program. If not, see <http://www.gnu.org/licenses/>.
+  this program. If not, see [http://www.gnu.org/licenses/].
 
   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
-  <http://www.fsf.org/licensing/licenses/gpl.html>
-  <http://www.gnu.org/licenses/gpl.html>
-
-  <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+  [http://www.fsf.org/licensing/licenses/gpl.html]
+  [http://www.gnu.org/licenses/gpl.html]
 
 ** SiSU uses:
   * Standard SiSU markup syntax,
@@ -48,12 +46,12 @@
   * Standard SiSU object citation numbering and system
 
 ** Hompages:
-  <http://www.jus.uio.no/sisu>
-  <http://www.sisudoc.org>
+  [http://www.jus.uio.no/sisu]
+  [http://www.sisudoc.org]
 
 ** Git
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/hub_options.rb;hb=HEAD>
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/hub_options.rb;hb=HEAD]
 
 =end
 module SiSU_Commandline
@@ -638,6 +636,9 @@ module SiSU_Commandline
           if ch =~/j/ then select_arr << '--images'
             ch=ch.gsub(/[j]/,'')
           end
+          if ch =~/J/ then select_arr << '--json'
+            ch=ch.gsub(/[J]/,'')
+          end
           if ch =~/N/ then select_arr << '--digests'
             ch=ch.gsub(/[N]/,'')
           end
@@ -1024,6 +1025,10 @@ module SiSU_Commandline
         =~/"--images"/) \
         ? { bool: true, set: :on }
         : { bool: false, set: :na }
+        act[:json]=(select_arr.inspect \
+        =~/"--json"/) \
+        ? { bool: true, set: :on }
+        : { bool: false, set: :na }
         if select_arr.inspect \
         =~/"--pdf"/
           if select_arr.inspect \
@@ -1490,6 +1495,7 @@ module SiSU_Commandline
         || act[:html][:set]==:on \
         || act[:html_seg][:set]==:on \
         || act[:html_scroll][:set]==:on \
+        || act[:json][:set]==:on \
         || act[:texinfo][:set]==:on \
         || act[:manpage][:set]==:on \
         || act[:hash_digests][:set]==:on \
@@ -1540,6 +1546,7 @@ module SiSU_Commandline
         || act[:html][:set]==:on \
         || act[:html_seg][:set]==:on \
         || act[:html_scroll][:set]==:on \
+        || act[:json][:set]==:on \
         || act[:texinfo][:set]==:on \
         || act[:manpage][:set]==:on \
         || act[:hash_digests][:set]==:on \
