@@ -7,11 +7,11 @@
 *** urls for output files
 
 ** Author: Ralph Amissah
-  <ralph@amissah.com>
-  <ralph.amissah@gmail.com>
+  [ralph@amissah.com]
+  [ralph.amissah@gmail.com]
 
 ** Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Ralph Amissah,
+  2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016 Ralph Amissah,
   All Rights Reserved.
 
 ** License: GPL 3 or later:
@@ -31,14 +31,12 @@
   more details.
 
   You should have received a copy of the GNU General Public License along with
-  this program. If not, see <http://www.gnu.org/licenses/>.
+  this program. If not, see [http://www.gnu.org/licenses/].
 
   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
-  <http://www.fsf.org/licensing/licenses/gpl.html>
-  <http://www.gnu.org/licenses/gpl.html>
-
-  <http://www.sisudoc.org/sisu/en/manifest/gpl.fsf.html>
+  [http://www.fsf.org/licensing/licenses/gpl.html]
+  [http://www.gnu.org/licenses/gpl.html]
 
 ** SiSU uses:
   * Standard SiSU markup syntax,
@@ -46,12 +44,12 @@
   * Standard SiSU object citation numbering and system
 
 ** Hompages:
-  <http://www.jus.uio.no/sisu>
-  <http://www.sisudoc.org>
+  [http://www.jus.uio.no/sisu]
+  [http://www.sisudoc.org]
 
 ** Git
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary>
-  <http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/urls.rb;hb=HEAD>
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=summary]
+  [http://git.sisudoc.org/gitweb/?p=code/sisu.git;a=blob;f=lib/sisu/urls.rb;hb=HEAD]
 
 =end
 module SiSU_Urls
@@ -337,6 +335,15 @@ module SiSU_Urls
         end
         self
       end
+      def json
+        {
+          cmd: '--js (json)',
+          viewer: @prog.web_browser,
+          f_pth: @md.file.output_path.json.dir + '/' \
+          + @md.file.base_filename.json,
+          fn: @fn[:json],
+        }
+      end
       def pdf
         def landscape
           {
@@ -622,6 +629,10 @@ module SiSU_Urls
               show.report(report_info.xml.scaffold_collapse)
               #show.maintenance(report_info.xml.scaffold_collapse)
             end
+            if @opt.act[:json][:set]==:on
+              show.report(report_info.json)
+              #show.maintenance(report_info.json)
+            end
             if (@opt.act[:pdf][:set]==:on \
             or @opt.act[:pdf_p][:set]==:on \
             or @opt.act[:pdf_l][:set]==:on)
